@@ -347,7 +347,7 @@ function define(string $constant_name, $value, #[Deprecated] bool $case_insensit
  * @return bool true if the named constant given by <i>name</i>
  * has been defined, false otherwise.
  */
-#[Pure]
+#[Pure(true)]
 function defined(string $constant_name): bool {}
 
 /**
@@ -476,6 +476,21 @@ function interface_exists(string $interface, bool $autoload = true): bool {}
 #[Pure(true)]
 function function_exists(string $function): bool {}
 
+/**
+ * Checks if the enum has been defined
+ * @link https://php.net/manual/en/function.enum-exists.php
+ * @param string $enum <p>
+ * The enum name. The name is matched in a case-insensitive manner.
+ * </p>
+ * @param bool $autoload [optional] <p>
+ * Whether or not to call autoload by default.
+ * </p>
+ * @return bool true if <i>enum</i> is a defined enum,
+ * false otherwise.
+ * @since 8.1
+ */
+function enum_exists(string $enum, bool $autoload = true): bool {}
+
 /**
  * Creates an alias for a class
  * @link https://php.net/manual/en/function.class-alias.php
@@ -500,7 +515,7 @@ function class_alias(string $class, string $alias, bool $autoload = true): bool
  * the returned array.
  * </p>
  */
-#[Pure]
+#[Pure(true)]
 function get_included_files(): array {}
 
 /**
@@ -508,7 +523,7 @@ function get_included_files(): array {}
  * @link https://php.net/manual/en/function.get-required-files.php
  * @return string[]
  */
-#[Pure]
+#[Pure(true)]
 function get_required_files(): array {}
 
 /**
@@ -694,7 +709,7 @@ function restore_exception_handler(): bool {}
  * the appendices.
  * </p>
  */
-#[Pure]
+#[Pure(true)]
 function get_declared_classes(): array {}
 
 /**
@@ -881,7 +896,7 @@ function get_extension_funcs(string $extension): array|false {}
  * </p>
  * @return array
  */
-#[Pure]
+#[Pure(true)]
 function get_defined_constants(bool $categorize = false): array {}
 
 /**
