@@ -227,7 +227,7 @@ interface Throwable extends Stringable
     /**
      * Returns the previous Throwable
      * @link https://php.net/manual/en/throwable.getprevious.php
-     * @return Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
+     * @return null|Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
      * @since 7.0
      */
     public function getPrevious();
@@ -320,7 +320,7 @@ class Exception implements Throwable
     /**
      * Returns previous Exception
      * @link https://php.net/manual/en/exception.getprevious.php
-     * @return Exception the previous <b>Exception</b> if available
+     * @return null|Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
      * or null otherwise.
      */
     #[Pure]
@@ -429,10 +429,11 @@ class Error implements Throwable
     /**
      * Returns the previous Throwable
      * @link https://php.net/manual/en/throwable.getprevious.php
-     * @return Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
+     * @return null|Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
      * @since 7.0
      */
     final public function getPrevious() {}
+
     /**
      * Gets a string representation of the thrown object
      * @link https://php.net/manual/en/throwable.tostring.php
@@ -882,3 +883,58 @@ final class InternalIterator implements Iterator
 
     public function rewind() {}
 }
+
+/**
+ * @since 8.1
+ */
+interface UnitEnum
+{
+    public string $name;
+
+    /**
+     * @return static[]
+     */
+    public static function cases(): array;
+}
+
+/**
+ * @since 8.1
+ */
+interface BackedEnum extends UnitEnum
+{
+    public string $value;
+
+    public static function from(int|string $scalar): static;
+
+    public static function tryFrom(int|string $scalar): ?static;
+}
+
+/**
+ * @since 8.1
+ * @internal
+ *
+ * Internal interface to ensure precise type inference
+ */
+interface IntBackedEnum extends BackedEnum
+{
+    public int $value;
+
+    public static function from(int $scalar): static;
+
+    public static function tryFrom(int $scalar): ?static;
+}
+
+/**
+ * @since 8.1
+ * @internal
+ *
+ * Internal interface to ensure precise type inference
+ */
+interface StringBackedEnum extends BackedEnum
+{
+    public string $value;
+
+    public static function from(string $scalar): static;
+
+    public static function tryFrom(string $scalar): ?static;
+}
