@@ -804,13 +804,20 @@ final class EvPeriodic extends EvWatcher
      * @param int $priority
      */
     public function __construct(
-        $offset, $interval, ?callable $reschedule_cb = null, callable $callback, $data = null, $priority = 0
+        $offset,
+        $interval,
+        ?callable $reschedule_cb,
+        callable $callback,
+        $data = null,
+        $priority = 0
     ) {}
 
     /**
      * Simply stops and restarts the periodic watcher again.
      *
      * Simply stops and restarts the periodic watcher again. This is only useful when attributes are changed.
+     *
+     * @return void
      */
     public function again() {}
 
@@ -845,13 +852,19 @@ final class EvPeriodic extends EvWatcher
      * @return EvPeriodic
      */
     final public static function createStopped(
-        $offset, $interval, ?callable $reschedule_cb = null, callable $callback, $data = null, $priority = 0
+        $offset,
+        $interval,
+        ?callable $reschedule_cb,
+        callable $callback,
+        $data = null,
+        $priority = 0
     ) {}
 
     /**
      * Configures the watcher
      * @param float $offset The same meaning as for {@see EvPeriodic::__construct}
      * @param float $interval The same meaning as for {@see EvPeriodic::__construct}
+     * @param null|callable $reschedule_cb The same meaning as for {@see EvPeriodic::__construct}
      * @return void
      */
     public function set($offset, $interval, $reschedule_cb = null) {}
@@ -1409,6 +1422,7 @@ final class EvLoop
      *
      * @param float $offset
      * @param float $interval
+     * @param callable $reschedule_cb
      * @param callable $callback
      * @param mixed $data
      * @param int $priority
@@ -1512,6 +1526,9 @@ final class EvLoop
      * @param float $timeout_interval
      */
     public static function defaultLoop(
-        $flags = Ev::FLAG_AUTO, $data = null, $io_interval = 0.0, $timeout_interval = 0.0
+        $flags = Ev::FLAG_AUTO,
+        $data = null,
+        $io_interval = 0.0,
+        $timeout_interval = 0.0
     ) {}
 }
