@@ -1,5 +1,7 @@
 <?php
 
+use JetBrains\PhpStorm\Pure;
+
 /**
  * The ReflectionReference class provides information about a reference.
  *
@@ -13,9 +15,7 @@ class ReflectionReference
     /**
      * ReflectionReference cannot be created explicitly.
      */
-    private function __construct()
-    {
-    }
+    private function __construct() {}
 
     /**
      * Returns ReflectionReference if array element is a reference, {@see null} otherwise
@@ -25,9 +25,7 @@ class ReflectionReference
      * @param int|string $key The key; either an integer or a string.
      * @return self|null
      */
-    public static function fromArrayElement(array $array, $key)
-    {
-    }
+    public static function fromArrayElement(array $array, $key) {}
 
     /**
      * Returns unique identifier for the reference. The return value format is unspecified
@@ -35,16 +33,13 @@ class ReflectionReference
      * @link https://php.net/manual/en/reflectionreference.getid.php
      * @return int|string Returns an integer or string of unspecified format.
      */
-    public function getId()
-    {
-    }
+    #[Pure]
+    public function getId() {}
 
     /**
      * ReflectionReference cannot be cloned
      *
      * @return void
      */
-    private function __clone()
-    {
-    }
+    private function __clone() {}
 }
