@@ -4,20 +4,20 @@
  * (PHP 5 &gt;= 5.5.5, PECL ZendOpcache &gt;= 7.0.2 )<br/>
  * Compiles and caches a PHP script without executing it
  * @link https://secure.php.net/manual/en/function.opcache-compile-file.php
- * @param string $file The path to the PHP script to be compiled.
+ * @param string $filename The path to the PHP script to be compiled.
  * @return bool
  * Returns <b>TRUE</b> if the opcode cache for <em>script</em> was
  * invalidated or if there was nothing to invalidate, or <b>FALSE</b> if the opcode
  * cache is disabled.
  * @since 5.5
  */
-function opcache_compile_file($file) { }
+function opcache_compile_file(string $filename): bool {}
 
 /**
  * (PHP 5 &gt;= 5.5.0, PECL ZendOpcache &gt;= 7.0.0 )<br/>
  * Invalidates a cached script
  * @link https://secure.php.net/manual/en/function.opcache-invalidate.php
- * @param string $script <p>The path to the script being invalidated.</p>
+ * @param string $filename <p>The path to the script being invalidated.</p>
  * @param bool $force [optional] <p> If set to <b>TRUE</b>, the script will be invalidated regardless of whether invalidation is necessary.</p>
  * @return bool
  * Returns <b>TRUE</b> if the opcode cache for <em>script</em> was
@@ -25,7 +25,7 @@ function opcache_compile_file($file) { }
  * cache is disabled.
  * @since 5.5
  */
-function opcache_invalidate($script, $force = false) { }
+function opcache_invalidate(string $filename, bool $force = false): bool {}
 
 /**
  * (PHP 5 &gt;= 5.5.0, PECL ZendOpcache &gt;= 7.0.0 )<br/>
@@ -34,34 +34,34 @@ function opcache_invalidate($script, $force = false) { }
  * @return bool Returns <b>TRUE</b> if the opcode cache was reset, or <b>FALSE</b> if the opcode cache is disabled.
  * @since 5.5
  */
-function opcache_reset() { }
+function opcache_reset(): bool {}
 
 /**
  * (PHP 5 &gt;= 5.5.5, PECL ZendOpcache &gt;= 7.0.2 )<br/>
  * Get status information about the cache
  * @link https://php.net/manual/en/function.opcache-get-status.php
- * @param bool $get_scripts <p>Include script specific state information</p>
- * @return array <p>Returns an array of information, optionally containing script specific state information</p>
+ * @param bool $include_scripts <p>Include script specific state information</p>
+ * @return array|false <p>Returns an array of information, optionally containing script specific state information</p>
  * @since 5.5
  */
-function opcache_get_status ($get_scripts = true) {}
+function opcache_get_status(bool $include_scripts = true): array|false {}
 
 /**
  * (PHP 5 &gt;= 5.5.5, PECL ZendOpcache &gt;= 7.0.2 )<br/>
  * Get configuration information about the cache
  * @link https://php.net/manual/en/function.opcache-get-configuration.php
- * @return array <p>Returns an array of information, including ini, blacklist and version</p>
+ * @return array|false <p>Returns an array of information, including ini, blacklist and version</p>
  * @since 5.5
  */
-function opcache_get_configuration() {}
+function opcache_get_configuration(): array|false {}
 
 /**
  * (PHP 5 &gt;= 5.6, PECL ZendOpcache &gt;= 7.0.4 )<br/>
  * This function checks if a PHP script has been cached in OPCache.
  * This can be used to more easily detect the "warming" of the cache for a particular script.
  * @link https://secure.php.net/manual/en/function.opcache-is-script-cached.php
- * @param string $file The path to the PHP script to be checked.
+ * @param string $filename The path to the PHP script to be checked.
  * @return bool Returns TRUE if file is cached in OPCache, FALSE otherwise.
  * @since 5.6
  */
-function opcache_is_script_cached($file) {}
+function opcache_is_script_cached(string $filename): bool {}
