@@ -1,5 +1,10 @@
 <?php
 
+use JetBrains\PhpStorm\ArrayShape;
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Internal\ReturnTypeContract as TypeContract;
+use JetBrains\PhpStorm\Pure;
+
 /**
  * Query language and locale information
  * @link https://php.net/manual/en/function.nl-langinfo.php
@@ -8,15 +13,15 @@
  * constant name of the element. The following is a list of constant names
  * for item that may be used and their description.
  * Some of these constants may not be defined or hold no value for certain
- * locales.
- * <table>
+ * locales.</p>
  * nl_langinfo Constants
+ * <table>
  * <tr valign="top">
  * <td>Constant</td>
  * <td>Description</td>
  * </tr>
- * <tr valign="top">
- * LC_TIME Category Constants</td>
+ * <tr colspan="2" valign="top" bgcolor="silver">
+ * <td >LC_TIME Category Constants</td>
  * </tr>
  * <tr valign="top">
  * <td>ABDAY_(1-7)</td>
@@ -78,8 +83,8 @@
  * <td>ERA_T_FMT</td>
  * <td>Time in alternate era format (string can be used in strftime).</td>
  * </tr>
- * <tr valign="top">
- * LC_MONETARY Category Constants</td>
+ * <tr colspan="2" valign="top" bgcolor="silver">
+ * <td>LC_MONETARY Category Constants</td>
  * </tr>
  * <tr valign="top">
  * <td>INT_CURR_SYMBOL</td>
@@ -139,21 +144,25 @@
  * </tr>
  * <tr valign="top">
  * <td>P_SIGN_POSN</td>
- * Returns 0 if parentheses surround the quantity and CURRENCY_SYMBOL.
+ * <td>Returns 0 if parentheses surround the quantity and CURRENCY_SYMBOL.</td>
+ * </tr>
+ * </table>
  * @return string|false the element as a string, or false if item
  * is not valid.
  */
-function nl_langinfo ($item) {}
+#[Pure]
+function nl_langinfo(int $item): string|false {}
 
 /**
  * Calculate the soundex key of a string
  * @link https://php.net/manual/en/function.soundex.php
- * @param string $str <p>
+ * @param string $string <p>
  * The input string.
  * </p>
  * @return string the soundex key as a string.
  */
-function soundex ($str) {}
+#[Pure]
+function soundex(string $string): string {}
 
 /**
  * Calculate Levenshtein distance between two strings
@@ -164,51 +173,53 @@ function soundex ($str) {}
  * Note: A second variant will take three additional parameters that define
  * the cost of insert, replace and delete operations. This is more general
  * and adaptive than variant one, but not as efficient.
- * @param string $str1 <p>
+ * @param string $string1 <p>
  * One of the strings being evaluated for Levenshtein distance.
  * </p>
- * @param string $str2 <p>
+ * @param string $string2 <p>
  * One of the strings being evaluated for Levenshtein distance.
  * </p>
- * @param int $cost_ins [optional] <p>
+ * @param int $insertion_cost [optional] <p>
  * Defines the cost of insertion.
  * </p>
- * @param int $cost_rep [optional] <p>
+ * @param int $replacement_cost [optional] <p>
  * Defines the cost of replacement.
  * </p>
- * @param int $cost_del [optional] <p>
+ * @param int $deletion_cost [optional] <p>
  * Defines the cost of deletion.
  * </p>
  * @return int This function returns the Levenshtein-Distance between the
  * two argument strings or -1, if one of the argument strings
  * is longer than the limit of 255 characters.
  */
-function levenshtein ($str1, $str2, $cost_ins = null, $cost_rep = null, $cost_del = null) {}
+function levenshtein(string $string1, string $string2, int $insertion_cost = 1, int $replacement_cost = 1, int $deletion_cost = 1): int {}
 
 /**
- * Return a specific character
+ * Generate a single-byte string from a number
  * @link https://php.net/manual/en/function.chr.php
- * @param int $ascii <p>
+ * @param int $codepoint <p>
  * The ascii code.
  * </p>
  * @return string the specified character.
  */
-function chr ($ascii) {}
+#[Pure]
+function chr(int $codepoint): string {}
 
 /**
- * Return ASCII value of character
+ * Convert the first byte of a string to a value between 0 and 255
  * @link https://php.net/manual/en/function.ord.php
- * @param string $string <p>
+ * @param string $character <p>
  * A character.
  * </p>
  * @return int the ASCII value as an integer.
  */
-function ord ($string) {}
+#[Pure]
+function ord(string $character): int {}
 
 /**
  * Parses the string into variables
  * @link https://php.net/manual/en/function.parse-str.php
- * @param string $str <p>
+ * @param string $string <p>
  * The input string.
  * </p>
  * @param array &$result [optional] <p>
@@ -218,15 +229,15 @@ function ord ($string) {}
  * </p>
  * @return void
  */
-function parse_str ($str, array &$result = null) {}
+function parse_str(string $string, &$result): void {}
 
 /**
  * Parse a CSV string into an array
  * @link https://php.net/manual/en/function.str-getcsv.php
- * @param string $input <p>
+ * @param string $string <p>
  * The string to parse.
  * </p>
- * @param string $delimiter [optional] <p>
+ * @param string $separator [optional] <p>
  * Set the field delimiter (one character only).
  * </p>
  * @param string $enclosure [optional] <p>
@@ -238,15 +249,16 @@ function parse_str ($str, array &$result = null) {}
  * </p>
  * @return array an indexed array containing the fields read.
  */
-function str_getcsv ($input, $delimiter = ",", $enclosure = '"', $escape = "\\") {}
+#[Pure]
+function str_getcsv(string $string, string $separator = ",", string $enclosure = '"', string $escape = "\\"): array {}
 
 /**
  * Pad a string to a certain length with another string
  * @link https://php.net/manual/en/function.str-pad.php
- * @param string $input <p>
+ * @param string $string <p>
  * The input string.
  * </p>
- * @param int $pad_length <p>
+ * @param int $length <p>
  * If the value of pad_length is negative,
  * less than, or equal to the length of the input string, no padding
  * takes place.
@@ -265,31 +277,36 @@ function str_getcsv ($input, $delimiter = ",", $enclosure = '"', $escape = "\\")
  * </p>
  * @return string the padded string.
  */
-function str_pad ($input, $pad_length, $pad_string = " ", $pad_type = STR_PAD_RIGHT) {}
+#[Pure]
+function str_pad(string $string, int $length, string $pad_string = " ", int $pad_type = STR_PAD_RIGHT): string {}
 
 /**
- * &Alias; <function>rtrim</function>
- * @see rtrim()
- * @link https://php.net/manual/en/function.chop.php
- * @param string $str The input string.
- * @param string $character_mask [optional]
+ * Alias:
+ * {@see rtrim}
+ * @param string $string The input string.
+ * @param string $characters [optional]
  * @return string the modified string.
+ * @link https://php.net/manual/en/function.chop.php
+ * @see rtrim()
  */
-function chop ($str, $character_mask = null) {}
+#[Pure]
+function chop(string $string, string $characters): string {}
 
 /**
- * &Alias; <function>strstr</function>
+ * Alias:
+ * {@see strstr}
  * @link https://php.net/manual/en/function.strchr.php
  * Note: This function is case-sensitive. For case-insensitive searches, use stristr().
  * Note: If you only want to determine if a particular needle occurs within haystack,
  * use the faster and less memory intensive function strpos() instead.
  *
  * @param string $haystack The input string.
- * @param mixed $needle If needle is not a string, it is converted to an integer and applied as the ordinal value of a character.
- * @param bool $part [optional] If TRUE, strstr() returns the part of the haystack before the first occurrence of the needle (excluding the needle).
+ * @param string $needle If needle is not a string, it is converted to an integer and applied as the ordinal value of a character.
+ * @param bool $before_needle [optional] If TRUE, strstr() returns the part of the haystack before the first occurrence of the needle (excluding the needle).
  * @return string|false Returns the portion of string, or FALSE if needle is not found.
  */
-function strchr ($haystack, $needle, $part = false) {}
+#[Pure]
+function strchr(string $haystack, string $needle, bool $before_needle = false): string|false {}
 
 /**
  * Return a formatted string
@@ -309,13 +326,14 @@ function strchr ($haystack, $needle, $part = false) {}
  * An optional sign specifier that forces a sign
  * (- or +) to be used on a number. By default, only the - sign is used
  * on a number if it's negative. This specifier forces positive numbers
- * to have the + sign attached as well, and was added in PHP 4.3.0.
- * @param mixed ...$args [optional] <p>
+ * to have the + sign attached as well, and was added in PHP 4.3.0.</p>
+ * @param string|int|float ...$values [optional] <p>
  * </p>
  * @return string a string produced according to the formatting string
  * format.
  */
-function sprintf ($format, ...$args) {}
+#[Pure]
+function sprintf(string $format, ...$values): string {}
 
 /**
  * Output a formatted string
@@ -324,11 +342,11 @@ function sprintf ($format, ...$args) {}
  * See sprintf for a description of
  * format.
  * </p>
- * @param mixed ...$args [optional] <p>
+ * @param string|int|float ...$values [optional] <p>
  * </p>
  * @return int the length of the outputted string.
  */
-function printf ($format, ...$args) {}
+function printf(string $format, ...$values): int {}
 
 /**
  * Output a formatted string
@@ -337,11 +355,11 @@ function printf ($format, ...$args) {}
  * See sprintf for a description of
  * format.
  * </p>
- * @param array $args <p>
+ * @param array $values <p>
  * </p>
  * @return int the length of the outputted string.
  */
-function vprintf ($format, array $args) {}
+function vprintf(string $format, array $values): int {}
 
 /**
  * Return a formatted string
@@ -350,47 +368,48 @@ function vprintf ($format, array $args) {}
  * See sprintf for a description of
  * format.
  * </p>
- * @param array $args <p>
+ * @param array $values <p>
  * </p>
  * @return string Return array values as a formatted string according to
  * format (which is described in the documentation
  * for sprintf).
  */
-function vsprintf ($format, array $args) {}
+#[Pure]
+function vsprintf(string $format, array $values): string {}
 
 /**
  * Write a formatted string to a stream
  * @link https://php.net/manual/en/function.fprintf.php
- * @param resource $handle &fs.file.pointer;
+ * @param resource $stream &fs.file.pointer;
  * @param string $format <p>
  * See sprintf for a description of
  * format.
  * </p>
- * @param mixed ...$args [optional] <p>
+ * @param mixed ...$values [optional] <p>
  * </p>
  * @return int the length of the string written.
  */
-function fprintf ($handle, $format, ...$args) {}
+function fprintf($stream, string $format, ...$values): int {}
 
 /**
  * Write a formatted string to a stream
  * @link https://php.net/manual/en/function.vfprintf.php
- * @param resource $handle <p>
+ * @param resource $stream <p>
  * </p>
  * @param string $format <p>
  * See sprintf for a description of
  * format.
  * </p>
- * @param array $args <p>
+ * @param array $values <p>
  * </p>
  * @return int the length of the outputted string.
  */
-function vfprintf ($handle, $format, array $args) {}
+function vfprintf($stream, string $format, array $values): int {}
 
 /**
  * Parses input from a string according to a format
  * @link https://php.net/manual/en/function.sscanf.php
- * @param string $str <p>
+ * @param string $string <p>
  * The input string being parsed.
  * </p>
  * @param string $format <p>
@@ -404,30 +423,30 @@ function vfprintf ($handle, $format, array $args) {}
  * i stands for integer with base detection.
  * n stands for number of characters processed so far.
  * </p>
- * @param mixed &...$_
- * @return array|int If only
+ * @param mixed &...$vars
+ * @return array|int|null If only
  * two parameters were passed to this function, the values parsed
  * will be returned as an array. Otherwise, if optional parameters are passed,
  * the function will return the number of assigned values. The optional
  * parameters must be passed by reference.
  */
-function sscanf ($str, $format, &...$_) {}
+function sscanf(string $string, string $format, #[TypeContract(exists: "int|null", notExists: "array|null")] mixed &...$vars): array|int|null {}
 
 /**
  * Parses input from a file according to a format
  * @link https://php.net/manual/en/function.fscanf.php
- * @param resource $handle &fs.file.pointer;
+ * @param resource $stream &fs.file.pointer;
  * @param string $format <p>
  * The specified format as described in the
  * sprintf documentation.
  * </p>
  * @param mixed &...$vars [optional]
- * @return array|int If only two parameters were passed to this function, the values parsed will be
+ * @return array|int|false|null If only two parameters were passed to this function, the values parsed will be
  * returned as an array. Otherwise, if optional parameters are passed, the
  * function will return the number of assigned values. The optional
  * parameters must be passed by reference.
  */
-function fscanf ($handle, $format, &...$vars) {}
+function fscanf($stream, string $format, #[TypeContract(exists: "int|false|null", notExists: "array|false|null")] mixed &...$vars): array|int|false|null {}
 
 /**
  * Parse a URL and return its components
@@ -460,12 +479,23 @@ function fscanf ($handle, $format, &...$vars) {}
  * If the component parameter is specified a
  * string is returned instead of an array.
  */
-function parse_url ($url, $component = -1) {}
+#[ArrayShape([
+    "scheme" => "string",
+    "host" => "string",
+    "port" => "int",
+    "user" => "string",
+    "pass" => "string",
+    "query" => "string",
+    "path" => "string",
+    "fragment" => "string",
+])]
+#[Pure]
+function parse_url(string $url, int $component = -1) {}
 
 /**
  * URL-encodes string
  * @link https://php.net/manual/en/function.urlencode.php
- * @param string $str <p>
+ * @param string $string <p>
  * The string to be encoded.
  * </p>
  * @return string a string in which all non-alphanumeric characters except
@@ -478,22 +508,24 @@ function parse_url ($url, $component = -1) {}
  * rawurlencode) in that for historical reasons, spaces
  * are encoded as plus (+) signs.
  */
-function urlencode ($str) {}
+#[Pure]
+function urlencode(string $string): string {}
 
 /**
  * Decodes URL-encoded string
  * @link https://php.net/manual/en/function.urldecode.php
- * @param string $str <p>
+ * @param string $string <p>
  * The string to be decoded.
  * </p>
  * @return string the decoded string.
  */
-function urldecode ($str) {}
+#[Pure]
+function urldecode(string $string): string {}
 
 /**
- * URL-encode according to RFC 1738
+ * URL-encode according to RFC 3986
  * @link https://php.net/manual/en/function.rawurlencode.php
- * @param string $str <p>
+ * @param string $string <p>
  * The URL to be encoded.
  * </p>
  * @return string a string in which all non-alphanumeric characters except
@@ -504,22 +536,24 @@ function urldecode ($str) {}
  * delimiters, and for protecting URLs from being mangled by transmission
  * media with character conversions (like some email systems).
  */
-function rawurlencode ($str) {}
+#[Pure]
+function rawurlencode(string $string): string {}
 
 /**
  * Decode URL-encoded strings
  * @link https://php.net/manual/en/function.rawurldecode.php
- * @param string $str <p>
+ * @param string $string <p>
  * The URL to be decoded.
  * </p>
  * @return string the decoded URL, as a string.
  */
-function rawurldecode ($str) {}
+#[Pure]
+function rawurldecode(string $string): string {}
 
 /**
  * Generate URL-encoded query string
  * @link https://php.net/manual/en/function.http-build-query.php
- * @param mixed $query_data <p>
+ * @param object|array $data <p>
  * May be an array or object containing properties.
  * </p>
  * <p>
@@ -538,18 +572,19 @@ function rawurldecode ($str) {}
  * This is meant to allow for legal variable names when the data is
  * decoded by PHP or another CGI application later on.
  * </p>
- * @param string $arg_separator [optional] <p>
+ * @param string|null $arg_separator [optional] <p>
  * arg_separator.output
  * is used to separate arguments, unless this parameter is specified,
  * and is then used.
  * </p>
- * @param int $enc_type By default, PHP_QUERY_RFC1738.
+ * @param int $encoding_type By default, PHP_QUERY_RFC1738.
  *  <p>If enc_type is PHP_QUERY_RFC1738, then encoding is performed per » RFC 1738 and the application/x-www-form-urlencoded media type,
  *  which implies that spaces are encoded as plus (+) signs.
  *  <p>If enc_type is PHP_QUERY_RFC3986, then encoding is performed according to » RFC 3986, and spaces will be percent encoded (%20).
  * @return string a URL-encoded string.
  */
-function http_build_query ($query_data, string $numeric_prefix = "", string $arg_separator = "&", int $enc_type = PHP_QUERY_RFC1738){}
+#[Pure]
+function http_build_query(object|array $data, string $numeric_prefix = "", ?string $arg_separator = "&", int $encoding_type = PHP_QUERY_RFC1738): string {}
 
 /**
  * Returns the target of a symbolic link
@@ -559,7 +594,7 @@ function http_build_query ($query_data, string $numeric_prefix = "", string $arg
  * </p>
  * @return string|false the contents of the symbolic link path or false on error.
  */
-function readlink ($path) {}
+function readlink(string $path): string|false {}
 
 /**
  * Gets information about a link
@@ -567,11 +602,12 @@ function readlink ($path) {}
  * @param string $path <p>
  * Path to the link.
  * </p>
- * @return int linkinfo returns the st_dev field
+ * @return int|false linkinfo returns the st_dev field
  * of the Unix C stat structure returned by the lstat
  * system call. Returns 0 or false in case of error.
  */
-function linkinfo ($path) {}
+#[Pure]
+function linkinfo(string $path): int|false {}
 
 /**
  * Creates a symbolic link
@@ -584,7 +620,7 @@ function linkinfo ($path) {}
  * </p>
  * @return bool true on success or false on failure.
  */
-function symlink ($target, $link) {}
+function symlink(string $target, string $link): bool {}
 
 /**
  * Create a hard link
@@ -593,7 +629,7 @@ function symlink ($target, $link) {}
  * @param string $link The link name.
  * @return bool true on success or false on failure.
  */
-function link (string $target , string $link):bool {}
+function link(string $target, string $link): bool {}
 
 /**
  * Deletes a file
@@ -601,10 +637,10 @@ function link (string $target , string $link):bool {}
  * @param string $filename <p>
  * Path to the file.
  * </p>
- * @param resource $context [optional] &note.context-support;
+ * @param resource $context [optional]
  * @return bool true on success or false on failure.
  */
-function unlink ($filename, $context = null):bool {}
+function unlink(string $filename, $context): bool {}
 
 /**
  * Execute an external program
@@ -612,7 +648,7 @@ function unlink ($filename, $context = null):bool {}
  * @param string $command <p>
  * The command that will be executed.
  * </p>
- * @param array $output [optional] <p>
+ * @param array &$output [optional] <p>
  * If the output argument is present, then the
  * specified array will be filled with every line of output from the
  * command. Trailing whitespace, such as \n, is not
@@ -622,13 +658,13 @@ function unlink ($filename, $context = null):bool {}
  * unset on the array before passing it to
  * exec.
  * </p>
- * @param int &$return_var [optional] <p>
+ * @param int &$result_code [optional] <p>
  * If the return_var argument is present
  * along with the output argument, then the
  * return status of the executed command will be written to this
  * variable.
  * </p>
- * @return string The last line from the result of the command. If you need to execute a
+ * @return string|false The last line from the result of the command. If you need to execute a
  * command and have all the data from the command passed directly back without
  * any interference, use the passthru function.
  * </p>
@@ -636,7 +672,7 @@ function unlink ($filename, $context = null):bool {}
  * To get the output of the executed command, be sure to set and use the
  * output parameter.
  */
-function exec ($command, array &$output = null, &$return_var = null) {}
+function exec(string $command, &$output, &$result_code): string|false {}
 
 /**
  * Execute an external program and display the output
@@ -644,7 +680,7 @@ function exec ($command, array &$output = null, &$return_var = null) {}
  * @param string $command <p>
  * The command that will be executed.
  * </p>
- * @param int &$return_var [optional] <p>
+ * @param int &$result_code [optional] <p>
  * If the return_var argument is present, then the
  * return status of the executed command will be written to this
  * variable.
@@ -652,7 +688,7 @@ function exec ($command, array &$output = null, &$return_var = null) {}
  * @return string|false the last line of the command output on success, and false
  * on failure.
  */
-function system ($command, &$return_var = null) {}
+function system(string $command, &$result_code): string|false {}
 
 /**
  * Escape shell metacharacters
@@ -662,7 +698,8 @@ function system ($command, &$return_var = null) {}
  * </p>
  * @return string The escaped string.
  */
-function escapeshellcmd ($command) {}
+#[Pure]
+function escapeshellcmd(string $command): string {}
 
 /**
  * Escape a string to be used as a shell argument
@@ -672,7 +709,8 @@ function escapeshellcmd ($command) {}
  * </p>
  * @return string The escaped string.
  */
-function escapeshellarg ($arg) {}
+#[Pure]
+function escapeshellarg(string $arg): string {}
 
 /**
  * Execute an external program and display raw output
@@ -680,28 +718,28 @@ function escapeshellarg ($arg) {}
  * @param string $command <p>
  * The command that will be executed.
  * </p>
- * @param int &$return_var [optional] <p>
+ * @param int &$result_code [optional] <p>
  * If the return_var argument is present, the
  * return status of the Unix command will be placed here.
  * </p>
- * @return void
+ * @return bool|null
  */
-function passthru ($command, &$return_var = null) {}
+function passthru(string $command, &$result_code): ?bool {}
 
 /**
  * Execute command via shell and return the complete output as a string
  * @link https://php.net/manual/en/function.shell-exec.php
- * @param string $cmd <p>
+ * @param string $command <p>
  * The command that will be executed.
  * </p>
- * @return string|null The output from the executed command or NULL if an error occurred or the command produces no output.
+ * @return string|false|null The output from the executed command or NULL if an error occurred or the command produces no output.
  */
-function shell_exec ($cmd) {}
+function shell_exec(string $command): string|false|null {}
 
 /**
  * Execute a command and open file pointers for input/output
  * @link https://php.net/manual/en/function.proc-open.php
- * @param array|string $cmd <p>
+ * @param array|string $command <p>
  * Execute a command and open file pointers for input/output
  * </p>
  * <p>
@@ -710,7 +748,7 @@ function shell_exec ($cmd) {}
  * (without going through a shell) and PHP will take care of any
  * necessary argument escaping.
  * </p>
- * @param array $descriptorspec <p>
+ * @param array $descriptor_spec <p>
  * An indexed array where the key represents the descriptor number and the
  * value represents how PHP will pass that descriptor to the child
  * process. 0 is stdin, 1 is stdout, while 2 is stderr.
@@ -745,11 +783,11 @@ function shell_exec ($cmd) {}
  * if you want to use the default value (the working dir of the current
  * PHP process)
  * </p>
- * @param array|null $env [optional] <p>
+ * @param array|null $env_vars [optional] <p>
  * An array with the environment variables for the command that will be
  * run, or null to use the same environment as the current PHP process
  * </p>
- * @param array $other_options [optional] <p>
+ * @param array|null $options [optional] <p>
  * Allows you to specify additional options. Currently supported options
  * include:
  * suppress_errors (windows only): suppresses errors generated by this
@@ -768,10 +806,10 @@ function shell_exec ($cmd) {}
  * proc_close when you are finished with it. On failure
  * returns false.
  */
-function proc_open ($cmd, array $descriptorspec, array &$pipes, $cwd = null, array $env = null, array $other_options = null) {}
+function proc_open(array|string $command, array $descriptor_spec, &$pipes, ?string $cwd, ?array $env_vars, ?array $options) {}
 
 /**
- * Close a process opened by <function>proc_open</function> and return the exit code of that process
+ * Close a process opened by {@see proc_open} and return the exit code of that process
  * @link https://php.net/manual/en/function.proc-close.php
  * @param resource $process <p>
  * The proc_open resource that will
@@ -779,7 +817,7 @@ function proc_open ($cmd, array $descriptorspec, array &$pipes, $cwd = null, arr
  * </p>
  * @return int the termination status of the process that was run.
  */
-function proc_close ($process) {}
+function proc_close($process): int {}
 
 /**
  * Kills a process opened by proc_open
@@ -796,10 +834,10 @@ function proc_close ($process) {}
  * </p>
  * @return bool the termination status of the process that was run.
  */
-function proc_terminate ($process, $signal = 15) {}
+function proc_terminate($process, int $signal = 15): bool {}
 
 /**
- * Get information about a process opened by <function>proc_open</function>
+ * Get information about a process opened by {@see proc_open}
  * @link https://php.net/manual/en/function.proc-get-status.php
  * @param resource $process <p>
  * The proc_open resource that will
@@ -873,20 +911,31 @@ function proc_terminate ($process, $signal = 15) {}
  * </td>
  * </tr>
  */
-function proc_get_status ($process) {}
+#[ArrayShape([
+    "command" => "string",
+    "pid" => "int",
+    "running" => "bool",
+    "signaled" => "bool",
+    "stopped" => "bool",
+    "exitcode" => "int",
+    "termsig" => "int",
+    "stopsig" => "int",
+])]
+#[LanguageLevelTypeAware(["8.0" => "array"], default: "array|false")]
+function proc_get_status($process) {}
 
 /**
  * Change the priority of the current process. <br/>
  * Since 7.2.0 supported on Windows platforms.
  * @link https://php.net/manual/en/function.proc-nice.php
- * @param int $increment <p>
+ * @param int $priority <p>
  * The increment value of the priority change.
  * </p>
  * @return bool true on success or false on failure.
  * If an error occurs, like the user lacks permission to change the priority,
  * an error of level E_WARNING is also generated.
  */
-function proc_nice ($increment) {}
+function proc_nice(int $priority): bool {}
 
 /**
  * Generate a random integer
@@ -896,7 +945,7 @@ function proc_nice ($increment) {}
  * @return int A pseudo random value between min
  * (or 0) and max (or getrandmax, inclusive).
  */
-function rand ($min = 0, $max = null) {}
+function rand(int $min = 0, int $max): int {}
 
 /**
  * Seed the random number generator
@@ -912,14 +961,15 @@ function rand ($min = 0, $max = null) {}
  * </p>
  * @return void
  */
-function srand ($seed = null, $mode = MT_RAND_MT19937) {}
+function srand(int $seed, int $mode = MT_RAND_MT19937): void {}
 
 /**
  * Show largest possible random value
  * @link https://php.net/manual/en/function.getrandmax.php
  * @return int The largest possible random value returned by rand
  */
-function getrandmax () {}
+#[Pure]
+function getrandmax(): int {}
 
 /**
  * Generate a random value via the Mersenne Twister Random Number Generator
@@ -933,10 +983,10 @@ function getrandmax () {}
  * @return int A random integer value between min (or 0)
  * and max (or mt_getrandmax, inclusive)
  */
-function mt_rand ($min = 0, $max = null) {}
+function mt_rand(int $min = 0, int $max): int {}
 
 /**
- * Seed the better random number generator
+ * Seeds the Mersenne Twister Random Number Generator
  * @link https://php.net/manual/en/function.mt-srand.php
  * @param int $seed [optional] <p>
  * An optional seed value
@@ -946,14 +996,15 @@ function mt_rand ($min = 0, $max = null) {}
  * </p>
  * @return void
  */
-function mt_srand ($seed = null, $mode = MT_RAND_MT19937) {}
+function mt_srand(int $seed, int $mode = MT_RAND_MT19937): void {}
 
 /**
  * Show largest possible random value
  * @link https://php.net/manual/en/function.mt-getrandmax.php
  * @return int the maximum random value returned by mt_rand
  */
-function mt_getrandmax () {}
+#[Pure]
+function mt_getrandmax(): int {}
 
 /**
  * Get port number associated with an Internet service and protocol
@@ -968,7 +1019,8 @@ function mt_getrandmax () {}
  * @return int|false the port number, or false if service or
  * protocol is not found.
  */
-function getservbyname ($service, $protocol) {}
+#[Pure]
+function getservbyname(string $service, string $protocol): int|false {}
 
 /**
  * Get Internet service which corresponds to port and protocol
@@ -980,54 +1032,61 @@ function getservbyname ($service, $protocol) {}
  * protocol is either "tcp"
  * or "udp" (in lowercase).
  * </p>
- * @return string the Internet service name as a string.
+ * @return string|false the Internet service name as a string.
  */
-function getservbyport ($port, $protocol) {}
+#[Pure]
+function getservbyport(int $port, string $protocol): string|false {}
 
 /**
  * Get protocol number associated with protocol name
  * @link https://php.net/manual/en/function.getprotobyname.php
- * @param string $name <p>
+ * @param string $protocol <p>
  * The protocol name.
  * </p>
- * @return int the protocol number or -1 if the protocol is not found.
+ * @return int|false the protocol number or -1 if the protocol is not found.
  */
-function getprotobyname ($name) {}
+#[Pure]
+function getprotobyname(string $protocol): int|false {}
 
 /**
  * Get protocol name associated with protocol number
  * @link https://php.net/manual/en/function.getprotobynumber.php
- * @param int $number <p>
+ * @param int $protocol <p>
  * The protocol number.
  * </p>
- * @return string the protocol name as a string.
+ * @return string|false the protocol name as a string.
  */
-function getprotobynumber ($number) {}
+#[Pure]
+function getprotobynumber(int $protocol): string|false {}
 
 /**
  * Gets PHP script owner's UID
  * @link https://php.net/manual/en/function.getmyuid.php
  * @return int|false the user ID of the current script, or false on error.
  */
-function getmyuid () {}
+#[Pure]
+function getmyuid(): int|false {}
 
 /**
  * Get PHP script owner's GID
  * @link https://php.net/manual/en/function.getmygid.php
  * @return int|false the group ID of the current script, or false on error.
  */
-function getmygid () {}
+#[Pure]
+function getmygid(): int|false {}
 
 /**
  * Gets PHP's process ID
  * @link https://php.net/manual/en/function.getmypid.php
  * @return int|false the current PHP process ID, or false on error.
  */
-function getmypid () {}
+#[Pure]
+function getmypid(): int|false {}
 
 /**
  * Gets the inode of the current script
  * @link https://php.net/manual/en/function.getmyinode.php
  * @return int|false the current script's inode as an integer, or false on error.
  */
-function getmyinode () {}
+#[Pure]
+function getmyinode(): int|false {}
