@@ -11,40 +11,39 @@ use stdClass;
 
 class PHPClass extends BasePHPClass
 {
-    /** @var false|string */
-    public $parentClass;
+    public false|string|null $parentClass = null;
     public array $interfaces = [];
     /** @var PHPProperty[] */
     public array $properties = [];
 
     /**
-     * @param ReflectionClass $clazz
-     * @return $this
+     * @param ReflectionClass $reflectionObject
+     * @return static
      */
-    public function readObjectFromReflection($clazz): self
+    public function readObjectFromReflection($reflectionObject): static
     {
-        $this->name = $clazz->getName();
-        $parent = $clazz->getParentClass();
+        $this->name = $reflectionObject->getName();
+        $parent = $reflectionObject->getParentClass();
         if ($parent !== false) {
             $this->parentClass = $parent->getName();
         }
-        $this->interfaces = $clazz->getInterfaceNames();
+        $this->interfaces = $reflectionObject->getInterfaceNames();
 
-        foreach ($clazz->getMethods() as $method) {
+        foreach ($reflectionObject->getMethods() as $method) {
             if ($method->getDeclaringClass()->getName() !== $this->name) {
                 continue;
             }
             $this->methods[$method->name] = (new PHPMethod())->readObjectFromReflection($method);
         }
 
-        foreach ($clazz->getReflectionConstants() as $constant) {
+        foreach ($reflectionObject->getReflectionConstants() as $constant) {
             if ($constant->getDeclaringClass()->getName() !== $this->name) {
                 continue;
             }
             $this->constants[$constant->name] = (new PHPConst())->readObjectFromReflection($constant);
         }
 
-        foreach ($clazz->getProperties() as $property) {
+        foreach ($reflectionObject->getProperties() as $property) {
             if ($property->getDeclaringClass()->getName() !== $this->name) {
                 continue;
             }
@@ -55,11 +54,13 @@ class PHPClass extends BasePHPClass
 
     /**
      * @param Class_ $node
-     * @return $this
+     * @return static
      */
-    public function readObjectFromStubNode($node): self
+    public function readObjectFromStubNode($node): static
     {
-        $this->name = $this->getFQN($node);
+        $this->name = self::getFQN($node);
+        $this->isFinal = $node->isFinal();
+        $this->availableVersionsRangeFromAttribute = self::findAvailableVersionsRangeFromAttribute($node->attrGroups);
         $this->collectTags($node);
         if (!empty($node->extends)) {
             $this->parentClass = '';
@@ -84,49 +85,42 @@ class PHPClass extends BasePHPClass
         if ($node->getDocComment() !== null) {
             $docBlock = DocBlockFactory::createInstance()->create($node->getDocComment()->getText());
             /** @var PropertyRead[] $properties */
-            $properties = array_merge($docBlock->getTagsByName("property-read"),
-                $docBlock->getTagsByName("property"));
+            $properties = array_merge(
+                $docBlock->getTagsByName('property-read'),
+                $docBlock->getTagsByName('property')
+            );
             foreach ($properties as $property) {
                 $propertyName = $property->getVariableName();
-                assert($propertyName !== "", "@property name is empty in class $this->name");
+                assert($propertyName !== '', "@property name is empty in class $this->name");
                 $newProperty = new PHPProperty($this->name);
                 $newProperty->is_static = false;
-                $newProperty->access = "public";
+                $newProperty->access = 'public';
                 $newProperty->name = $propertyName;
                 $newProperty->parentName = $this->name;
-                $newProperty->type = "" . $property->getType();
-                assert(!array_key_exists($propertyName, $this->properties),
-                    "Property '$propertyName' is already declared in class '$this->name'");
+                $newProperty->type = '' . $property->getType();
+                assert(
+                    !array_key_exists($propertyName, $this->properties),
+                    "Property '$propertyName' is already declared in class '$this->name'"
+                );
                 $this->properties[$propertyName] = $newProperty;
             }
         }
 
-
         return $this;
     }
 
-    public function readMutedProblems($jsonData): void
+    public function readMutedProblems(stdClass|array $jsonData): void
     {
-        /**@var stdClass $class */
         foreach ($jsonData as $class) {
             if ($class->name === $this->name) {
                 if (!empty($class->problems)) {
-                    /**@var stdClass $problem */
                     foreach ($class->problems as $problem) {
-                        switch ($problem) {
-                            case 'wrong parent':
-                                $this->mutedProblems[] = StubProblemType::WRONG_PARENT;
-                                break;
-                            case 'wrong interface':
-                                $this->mutedProblems[] = StubProblemType::WRONG_INTERFACE;
-                                break;
-                            case 'missing class':
-                                $this->mutedProblems[] = StubProblemType::STUB_IS_MISSED;
-                                break;
-                            default:
-                                $this->mutedProblems[] = -1;
-                                break;
-                        }
+                        $this->mutedProblems[] = match ($problem) {
+                            'wrong parent' => StubProblemType::WRONG_PARENT,
+                            'wrong interface' => StubProblemType::WRONG_INTERFACE,
+                            'missing class' => StubProblemType::STUB_IS_MISSED,
+                            default => -1,
+                        };
                     }
                 }
                 if (!empty($class->methods)) {
