@@ -3,6 +3,7 @@ declare(strict_types=1);
 
 namespace StubTests\Model;
 
+use phpDocumentor\Reflection\DocBlock\Tags\Param;
 use PhpParser\Node\Stmt\ClassMethod;
 use ReflectionMethod;
 use stdClass;
@@ -44,10 +45,12 @@ class PHPMethod extends PHPFunction
      */
     public function readObjectFromStubNode($node): static
     {
-        $this->parentName = $this->getFQN($node->getAttribute('parent'));
+        $this->parentName = self::getFQN($node->getAttribute('parent'));
         $this->name = $node->name->name;
+        $typesFromAttribute = self::findTypesFromAttribute($node->attrGroups);
         $this->availableVersionsRangeFromAttribute = self::findAvailableVersionsRangeFromAttribute($node->attrGroups);
-        $this->returnType = self::convertParsedTypeToString($node->getReturnType());
+        $this->returnTypesFromAttribute = $typesFromAttribute;
+        array_push($this->returnTypesFromSignature, ...self::convertParsedTypeToArray($node->getReturnType()));
         $this->collectTags($node);
         $this->checkDeprecationTag($node);
         $this->checkReturnTag($node);
@@ -59,6 +62,15 @@ class PHPMethod extends PHPFunction
             $this->parameters[] = (new PHPParameter())->readObjectFromStubNode($parameter);
         }
 
+        foreach ($this->parameters as $parameter) {
+            $relatedParamTags = array_filter($this->paramTags, fn (Param $tag) => $tag->getVariableName() === $parameter->name);
+            /** @var Param $relatedParamTag */
+            $relatedParamTag = array_pop($relatedParamTags);
+            if (!empty($relatedParamTag)) {
+                $parameter->isOptional = $parameter->isOptional || str_contains((string)$relatedParamTag->getDescription(), '[optional]');
+            }
+        }
+
         $this->isFinal = $node->isFinal();
         $this->isStatic = $node->isStatic();
         if ($node->isPrivate()) {
@@ -83,8 +95,11 @@ class PHPMethod extends PHPFunction
                             'deprecated method' => StubProblemType::FUNCTION_IS_DEPRECATED,
                             'absent in meta' => StubProblemType::ABSENT_IN_META,
                             'wrong access' => StubProblemType::FUNCTION_ACCESS,
+                            'has duplicate in stubs' => StubProblemType::HAS_DUPLICATION,
                             'has nullable typehint' => StubProblemType::HAS_NULLABLE_TYPEHINT,
                             'has union typehint' => StubProblemType::HAS_UNION_TYPEHINT,
+                            'wrong return typehint' => StubProblemType::WRONG_RETURN_TYPEHINT,
+                            'has type mismatch in signature and phpdoc' => StubProblemType::TYPE_IN_PHPDOC_DIFFERS_FROM_SIGNATURE,
                             default => -1
                         };
                     }
