@@ -11,6 +11,7 @@ use PhpParser\NodeVisitorAbstract;
 use PhpParser\ParserFactory;
 use RecursiveDirectoryIterator;
 use RecursiveIteratorIterator;
+use RuntimeException;
 use SplFileInfo;
 use StubTests\Model\StubsContainer;
 use StubTests\Parsers\Visitors\ASTVisitor;
@@ -23,13 +24,22 @@ class StubParser
 {
     private static ?StubsContainer $stubs = null;
 
+    /**
+     * @return StubsContainer
+     * @throws LogicException
+     * @throws RuntimeException
+     * @throws UnexpectedValueException
+     */
     public static function getPhpStormStubs(): StubsContainer
     {
         self::$stubs = new StubsContainer();
         $visitor = new ASTVisitor(self::$stubs);
         $coreStubVisitor = new CoreStubASTVisitor(self::$stubs);
-        self::processStubs($visitor, $coreStubVisitor,
-            fn(SplFileInfo $file): bool => $file->getFilename() !== '.phpstorm.meta.php');
+        self::processStubs(
+            $visitor,
+            $coreStubVisitor,
+            fn (SplFileInfo $file): bool => $file->getFilename() !== '.phpstorm.meta.php'
+        );
 
         $jsonData = json_decode(file_get_contents(__DIR__ . '/../TestData/mutedProblems.json'));
         foreach (self::$stubs->getInterfaces() as $interface) {
@@ -78,8 +88,12 @@ class StubParser
             $traverser->addVisitor(new ParentConnector());
             $traverser->addVisitor($nameResolver);
             if ($coreStubASTVisitor !== null && self::stubBelongsToCore($file, $coreStubDirectories)) {
+                $coreStubASTVisitor->sourceFilePath = $file->getPath();
                 $traverser->addVisitor($coreStubASTVisitor);
             } else {
+                if ($visitor instanceof ASTVisitor) {
+                    $visitor->sourceFilePath = $file->getPath();
+                }
                 $traverser->addVisitor($visitor);
             }
             $traverser->traverse($parser->parse($code, new StubsParserErrorHandler()));
