@@ -31,8 +31,10 @@ class StubsMetaInternalTagTest extends BaseStubsTest
         $functions = PhpStormStubsSingleton::getPhpStormStubs()->getFunctions();
         foreach ($functions as $function) {
             if ($function->hasInternalMetaTag) {
-                $reflectionFunctions = array_filter(ReflectionStubsSingleton::getReflectionStubs()->getFunctions(),
-                    fn ($refFunction) => $refFunction->name === $function->name);
+                $reflectionFunctions = array_filter(
+                    ReflectionStubsSingleton::getReflectionStubs()->getFunctions(),
+                    fn ($refFunction) => $refFunction->name === $function->name
+                );
                 $reflectionFunction = array_pop($reflectionFunctions);
                 if (!$reflectionFunction->hasMutedProblem(StubProblemType::ABSENT_IN_META)) {
                     self::checkInternalMetaInOverride($function->name);
@@ -51,8 +53,10 @@ class StubsMetaInternalTagTest extends BaseStubsTest
                 if ($method->hasInternalMetaTag) {
                     $refClass = ReflectionStubsSingleton::getReflectionStubs()->getClass($className);
                     if ($refClass !== null) {
-                        $reflectionMethods = array_filter($refClass->methods,
-                            fn ($refMethod) => $refMethod->name === $methodName);
+                        $reflectionMethods = array_filter(
+                            $refClass->methods,
+                            fn ($refMethod) => $refMethod->name === $methodName
+                        );
                         /** @var PHPMethod $reflectionMethod */
                         $reflectionMethod = array_pop($reflectionMethods);
                         if ($reflectionMethod->hasMutedProblem(StubProblemType::ABSENT_IN_META)) {
@@ -74,7 +78,10 @@ class StubsMetaInternalTagTest extends BaseStubsTest
      */
     private static function checkInternalMetaInOverride(string $elementName): void
     {
-        self::assertContains($elementName, self::$overriddenFunctionsInMeta,
-            "$elementName contains @meta in phpdoc but isn't added to 'override()' functions in meta file");
+        self::assertContains(
+            $elementName,
+            self::$overriddenFunctionsInMeta,
+            "$elementName contains @meta in phpdoc but isn't added to 'override()' functions in meta file"
+        );
     }
 }
