@@ -21,10 +21,14 @@ class StubsParameterNamesTest extends BaseStubsTest
     public function testFunctionsParameterNames(PHPFunction $function, PHPParameter $parameter)
     {
         $phpstormFunction = PhpStormStubsSingleton::getPhpStormStubs()->getFunction($function->name);
-        self::assertNotEmpty(array_filter($phpstormFunction->parameters,
-            fn (PHPParameter $stubParameter) => $stubParameter->name === $parameter->name),
-            "Function {$function->name} has signature {$function->name}(" . self::printParameters($function->parameters) . ')' .
-            " but stub function has signature {$phpstormFunction->name}(" . self::printParameters($phpstormFunction->parameters) . ')');
+        self::assertNotEmpty(
+            array_filter(
+                $phpstormFunction->parameters,
+                fn (PHPParameter $stubParameter) => $stubParameter->name === $parameter->name
+            ),
+            "Function $function->name has signature $function->name(" . self::printParameters($function->parameters) . ')' .
+            " but stub function has signature $phpstormFunction->name(" . self::printParameters($phpstormFunction->parameters) . ')'
+        );
     }
 
     /**
@@ -40,10 +44,14 @@ class StubsParameterNamesTest extends BaseStubsTest
         } else {
             $stubMethod = PhpStormStubsSingleton::getPhpStormStubs()->getInterface($className)->methods[$methodName];
         }
-        self::assertNotEmpty(array_filter($stubMethod->parameters,
-            fn (PHPParameter $stubParameter) => $stubParameter->name === $reflectionParameter->name),
+        self::assertNotEmpty(
+            array_filter(
+                $stubMethod->parameters,
+                fn (PHPParameter $stubParameter) => $stubParameter->name === $reflectionParameter->name
+            ),
             "Method $className::$methodName has signature $methodName(" . self::printParameters($reflectionMethod->parameters) . ')' .
-            " but stub function has signature $methodName(" . self::printParameters($stubMethod->parameters) . ')');
+            " but stub function has signature $methodName(" . self::printParameters($stubMethod->parameters) . ')'
+        );
     }
 
     /**
