@@ -1278,13 +1278,13 @@ function zip_entry_open($zip_dp, $zip_entry, string $mode = 'rb'): bool {}
  * (PHP 4 &gt;= 4.1.0, PHP 5 &gt;= 5.2.0, PECL zip &gt;= 1.0.0)<br/>
  * Close a directory entry
  * @link https://php.net/manual/en/function.zip-entry-close.php
- * @param resource $zip_ent <p>
+ * @param resource $zip_entry <p>
  * A directory entry previously opened <b>zip_entry_open</b>.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  * @deprecated 8.0 Use {@link ZipArchive} instead.
  */
-function zip_entry_close($zip_ent): bool {}
+function zip_entry_close($zip_entry): bool {}
 
 /**
  * (PHP 4 &gt;= 4.1.0, PHP 5 &gt;= 5.2.0, PECL zip &gt;= 1.0.0)<br/>
