@@ -18,7 +18,7 @@ use JetBrains\PhpStorm\Pure;
  * </p>
  * @return int|false the number of (uncompressed) bytes read from the file, or FALSE on error
  */
-function readgzfile (string $filename, int $use_include_path = 0): int|false {}
+function readgzfile(string $filename, int $use_include_path = 0): int|false {}
 
 /**
  * Rewind the position of a gz-file pointer
@@ -29,8 +29,7 @@ function readgzfile (string $filename, int $use_include_path = 0): int|false {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function gzrewind ($stream): bool
-{}
+function gzrewind($stream): bool {}
 
 /**
  * Close an open gz-file pointer
@@ -41,8 +40,7 @@ function gzrewind ($stream): bool
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function gzclose ($stream): bool
-{}
+function gzclose($stream): bool {}
 
 /**
  * Test for EOF on a gz-file pointer
@@ -54,7 +52,7 @@ function gzclose ($stream): bool
  * @return bool <b>TRUE</b> if the gz-file pointer is at EOF or an error occurs;
  * otherwise returns <b>FALSE</b>.
  */
-function gzeof ($stream): bool {}
+function gzeof($stream): bool {}
 
 /**
  * Get character from gz-file pointer
@@ -65,7 +63,7 @@ function gzeof ($stream): bool {}
  * </p>
  * @return string|false The uncompressed character or <b>FALSE</b> on EOF (unlike <b>gzeof</b>).
  */
-function gzgetc ($stream): string|false {}
+function gzgetc($stream): string|false {}
 
 /**
  * Get line from file pointer
@@ -79,7 +77,7 @@ function gzgetc ($stream): string|false {}
  * </p>
  * @return string|false The uncompressed string, or <b>FALSE</b> on error.
  */
-function gzgets ($stream, ?int $length = 1024): string|false {}
+function gzgets($stream, ?int $length = 1024): string|false {}
 
 /**
  * Get line from gz-file pointer and strip HTML tags
@@ -99,8 +97,7 @@ function gzgets ($stream, ?int $length = 1024): string|false {}
  * @removed 8.0
  */
 #[Deprecated(since: "7.3")]
-function gzgetss ($zp, int $length, $allowable_tags)
-{}
+function gzgetss($zp, int $length, $allowable_tags) {}
 
 /**
  * Binary-safe gz-file read
@@ -114,7 +111,7 @@ function gzgetss ($zp, int $length, $allowable_tags)
  * </p>
  * @return string|false The data that have been read.
  */
-function gzread ($stream, int $length): string|false {}
+function gzread($stream, int $length): string|false {}
 
 /**
  * Open gz-file
@@ -143,7 +140,7 @@ function gzread ($stream, int $length): string|false {}
  * <p>
  * If the open fails, the function returns <b>FALSE</b>.
  */
-function gzopen (string $filename, string $mode, int $use_include_path = 0) {}
+function gzopen(string $filename, string $mode, int $use_include_path = 0) {}
 
 /**
  * Output all remaining data on a gz-file pointer
@@ -155,8 +152,7 @@ function gzopen (string $filename, string $mode, int $use_include_path = 0) {}
  * @return int The number of uncompressed characters read from <i>gz</i>
  * and passed through to the input, or <b>FALSE</b> on error.
  */
-function gzpassthru ($stream): int
-{}
+function gzpassthru($stream): int {}
 
 /**
  * Seek on a gz-file pointer
@@ -180,8 +176,7 @@ function gzpassthru ($stream): int
  * @return int Upon success, returns 0; otherwise, returns -1. Note that seeking
  * past EOF is not considered an error.
  */
-function gzseek ($stream, int $offset, int $whence = SEEK_SET): int
-{}
+function gzseek($stream, int $offset, int $whence = SEEK_SET): int {}
 
 /**
  * Tell gz-file pointer read/write position
@@ -192,7 +187,7 @@ function gzseek ($stream, int $offset, int $whence = SEEK_SET): int
  * </p>
  * @return int|false The position of the file pointer or <b>FALSE</b> if an error occurs.
  */
-function gztell ($stream): int|false {}
+function gztell($stream): int|false {}
 
 /**
  * Binary-safe gz-file write
@@ -219,8 +214,7 @@ function gztell ($stream): int|false {}
  * @return int|false the number of (uncompressed) bytes written to the given gz-file
  * stream.
  */
-function gzwrite ($stream, string $data, ?int $length): int|false
-{}
+function gzwrite($stream, string $data, ?int $length): int|false {}
 
 /**
  * Alias of <b>gzwrite</b>
@@ -230,7 +224,7 @@ function gzwrite ($stream, string $data, ?int $length): int|false
  * @param int|null $length [optional]
  * @return int|false
  */
-function gzputs ($stream, string $data, ?int $length): int|false {}
+function gzputs($stream, string $data, ?int $length): int|false {}
 
 /**
  * Read entire gz-file into an array
@@ -244,7 +238,7 @@ function gzputs ($stream, string $data, ?int $length): int|false {}
  * </p>
  * @return array|false An array containing the file, one line per cell.
  */
-function gzfile (string $filename, int $use_include_path = 0): array|false {}
+function gzfile(string $filename, int $use_include_path = 0): array|false {}
 
 /**
  * Compress a string
@@ -265,7 +259,7 @@ function gzfile (string $filename, int $use_include_path = 0): array|false {}
  * @return string|false The compressed string or <b>FALSE</b> if an error occurred.
  */
 #[Pure]
-function gzcompress (string $data, int $level = -1, int $encoding = ZLIB_ENCODING_DEFLATE): string|false {}
+function gzcompress(string $data, int $level = -1, int $encoding = ZLIB_ENCODING_DEFLATE): string|false {}
 
 /**
  * Uncompress a compressed string
@@ -284,7 +278,7 @@ function gzcompress (string $data, int $level = -1, int $encoding = ZLIB_ENCODIN
  * </p>
  */
 #[Pure]
-function gzuncompress (string $data, int $max_length = 0): string|false {}
+function gzuncompress(string $data, int $max_length = 0): string|false {}
 
 /**
  * Deflate a string
@@ -303,7 +297,7 @@ function gzuncompress (string $data, int $max_length = 0): string|false {}
  * @return string|false The deflated string or <b>FALSE</b> if an error occurred.
  */
 #[Pure]
-function gzdeflate (string $data, int $level = -1, int $encoding = ZLIB_ENCODING_RAW): string|false {}
+function gzdeflate(string $data, int $level = -1, int $encoding = ZLIB_ENCODING_RAW): string|false {}
 
 /**
  * Inflate a deflated string
@@ -322,7 +316,7 @@ function gzdeflate (string $data, int $level = -1, int $encoding = ZLIB_ENCODING
  * </p>
  */
 #[Pure]
-function gzinflate (string $data, int $max_length = 0): string|false {}
+function gzinflate(string $data, int $max_length = 0): string|false {}
 
 /**
  * Create a gzip compressed string
@@ -352,7 +346,7 @@ function gzinflate (string $data, int $max_length = 0): string|false {}
  * @return string|false The encoded string, or <b>FALSE</b> if an error occurred.
  */
 #[Pure]
-function gzencode (string $data, int $level = -1, int $encoding = FORCE_GZIP): string|false {}
+function gzencode(string $data, int $level = -1, int $encoding = FORCE_GZIP): string|false {}
 
 /**
  * Decodes a gzip compressed string
@@ -367,8 +361,7 @@ function gzencode (string $data, int $level = -1, int $encoding = FORCE_GZIP): s
  * @since 5.4
  */
 #[Pure]
-function gzdecode (string $data, int $max_length): string|false
-{}
+function gzdecode(string $data, int $max_length): string|false {}
 
 /**
  * Compress data with the specified encoding
@@ -383,7 +376,7 @@ function gzdecode (string $data, int $max_length): string|false
  * @since 5.4
  */
 #[Pure]
-function zlib_encode (string $data, int $encoding, int $level = -1): string|false {}
+function zlib_encode(string $data, int $encoding, int $level = -1): string|false {}
 
 /**
  * Uncompress any raw/gzip/zlib encoded data
@@ -396,8 +389,7 @@ function zlib_encode (string $data, int $encoding, int $level = -1): string|fals
  * @since 5.4
  */
 #[Pure]
-function zlib_decode (string $data, int $max_length): string|false
-{}
+function zlib_decode(string $data, int $max_length): string|false {}
 
 /**
  * Returns the coding type used for output compression
@@ -406,7 +398,7 @@ function zlib_decode (string $data, int $max_length): string|false
  * or <b>FALSE</b>.
  */
 #[Pure]
-function zlib_get_coding_type (): string|false {}
+function zlib_get_coding_type(): string|false {}
 
 /**
  * ob_start callback function to gzip output buffer
@@ -415,7 +407,7 @@ function zlib_get_coding_type (): string|false {}
  * @param int $flags
  * @return string|false
  */
-function ob_gzhandler (string $data, int $flags): string|false {}
+function ob_gzhandler(string $data, int $flags): string|false {}
 
 /**
  * Initialize an incremental deflate context
@@ -440,7 +432,7 @@ function ob_gzhandler (string $data, int $flags): string|false {}
  */
 #[Pure]
 #[LanguageLevelTypeAware(["8.0" => "DeflateContext|false"], default: "resource|false")]
-function deflate_init (int $encoding, array $options = array()) {}
+function deflate_init(int $encoding, array $options = []) {}
 
 /**
  * Incrementally deflate data
@@ -463,7 +455,7 @@ function deflate_init (int $encoding, array $options = array()) {}
  * </p>
  * @since 7.0
  */
-function deflate_add (#[LanguageLevelTypeAware(["8.0" => "DeflateContext"], default: "resource")] $context, string $data, int $flush_mode = ZLIB_SYNC_FLUSH): string|false {}
+function deflate_add(#[LanguageLevelTypeAware(["8.0" => "DeflateContext"], default: "resource")] $context, string $data, int $flush_mode = ZLIB_SYNC_FLUSH): string|false {}
 
 /**
  * Initialize an incremental inflate context
@@ -488,7 +480,7 @@ function deflate_add (#[LanguageLevelTypeAware(["8.0" => "DeflateContext"], defa
  */
 #[Pure]
 #[LanguageLevelTypeAware(["8.0" => "InflateContext|false"], default: "resource|false")]
-function inflate_init (int $encoding, array $options = array()) {}
+function inflate_init(int $encoding, array $options = []) {}
 
 /**
  * Incrementally inflate encoded data
@@ -511,7 +503,7 @@ function inflate_init (int $encoding, array $options = array()) {}
  * </p>
  * @since 7.0
  */
-function inflate_add (#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context, string $data, int $flush_mode = ZLIB_SYNC_FLUSH): string|false {}
+function inflate_add(#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context, string $data, int $flush_mode = ZLIB_SYNC_FLUSH): string|false {}
 
 /**
  * Get number of bytes read so far
@@ -520,7 +512,7 @@ function inflate_add (#[LanguageLevelTypeAware(["8.0" => "InflateContext"], defa
  * @since 7.2
  */
 #[Pure]
-function inflate_get_read_len (#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context): int{}
+function inflate_get_read_len(#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context): int {}
 
 /**
  * Get decompression status
@@ -529,32 +521,34 @@ function inflate_get_read_len (#[LanguageLevelTypeAware(["8.0" => "InflateContex
  * @since 7.2
  */
 #[Pure]
-function  inflate_get_status(#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context): int {}
+function inflate_get_status(#[LanguageLevelTypeAware(["8.0" => "InflateContext"], default: "resource")] $context): int {}
 
 /**
  * @since 8.0
  */
-class InflateContext{
+class InflateContext
+{
     /**
      * Use inflate_init() instead
      * @see inflate_init()
      */
-    private function __construct(){}
+    private function __construct() {}
 }
 
 /**
  * @since 8.0
  */
-class DeflateContext{
+class DeflateContext
+{
     /**
      * Use deflate_init() instead
      * @see deflate_init()
      */
-    private function __construct(){}
+    private function __construct() {}
 }
 
-define ('FORCE_GZIP', 31);
-define ('FORCE_DEFLATE', 15);
+define('FORCE_GZIP', 31);
+define('FORCE_DEFLATE', 15);
 /** @link https://php.net/manual/en/zlib.constants.php */
 define('ZLIB_ENCODING_RAW', -15);
 /** @link https://php.net/manual/en/zlib.constants.php */
@@ -562,28 +556,27 @@ define('ZLIB_ENCODING_GZIP', 31);
 /** @link https://php.net/manual/en/zlib.constants.php */
 define('ZLIB_ENCODING_DEFLATE', 15);
 
-define ('ZLIB_NO_FLUSH', 0);
-define ('ZLIB_PARTIAL_FLUSH', 1);
-define ('ZLIB_SYNC_FLUSH', 2);
-define ('ZLIB_FULL_FLUSH', 3);
-define ('ZLIB_BLOCK', 5);
-define ('ZLIB_FINISH', 4);
+define('ZLIB_NO_FLUSH', 0);
+define('ZLIB_PARTIAL_FLUSH', 1);
+define('ZLIB_SYNC_FLUSH', 2);
+define('ZLIB_FULL_FLUSH', 3);
+define('ZLIB_BLOCK', 5);
+define('ZLIB_FINISH', 4);
 
-define ('ZLIB_FILTERED', 1);
-define ('ZLIB_HUFFMAN_ONLY', 2);
-define ('ZLIB_RLE', 3);
-define ('ZLIB_FIXED', 4);
-define ('ZLIB_DEFAULT_STRATEGY', 0);
-define ('ZLIB_OK', 0);
-define ('ZLIB_STREAM_END', 1);
-define ('ZLIB_NEED_DICT', 2);
-define ('ZLIB_ERRNO', -1);
-define ('ZLIB_STREAM_ERROR', -2);
-define ('ZLIB_DATA_ERROR', -3);
-define ('ZLIB_MEM_ERROR', -4);
-define ('ZLIB_BUF_ERROR', -5);
-define ('ZLIB_VERSION_ERROR', -6);
+define('ZLIB_FILTERED', 1);
+define('ZLIB_HUFFMAN_ONLY', 2);
+define('ZLIB_RLE', 3);
+define('ZLIB_FIXED', 4);
+define('ZLIB_DEFAULT_STRATEGY', 0);
+define('ZLIB_OK', 0);
+define('ZLIB_STREAM_END', 1);
+define('ZLIB_NEED_DICT', 2);
+define('ZLIB_ERRNO', -1);
+define('ZLIB_STREAM_ERROR', -2);
+define('ZLIB_DATA_ERROR', -3);
+define('ZLIB_MEM_ERROR', -4);
+define('ZLIB_BUF_ERROR', -5);
+define('ZLIB_VERSION_ERROR', -6);
 
-
-define ('ZLIB_VERSION', 'zlib_version_string'); // This is set to the zlib version
-define ('ZLIB_VERNUM', 'zlib_version_string'); // This is set to the zlib version
+define('ZLIB_VERSION', 'zlib_version_string'); // This is set to the zlib version
+define('ZLIB_VERNUM', 'zlib_version_string'); // This is set to the zlib version
